package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`"``!````T!T```````!``````````""X````
M````!P``@$``.``*`$``'@`=``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```#0I0``````
M`-"E````````T*4````````/``````````\``````````0`````````#``!P
M!````'`"````````<`(```````!P`@```````!@`````````&``````````(
M``````````$````%````````````````````````````````````Y*4`````
M``#DI0```````````0```````0````8```#PKP```````/"O`0``````\*\!
M``````!8`P```````)`3```````````!```````"````!````(@$````````
MB`0```````"(!````````'`"````````<`(````````(``````````0````$
M````0`0```````!`!````````$`$````````1`````````!$``````````0`
M````````4>5T9`<`````````````````````````````````````````````
M````````````$`````````!2Y71D!````/"O````````\*\!``````#PKP$`
M`````!``````````$``````````!````````````````````````````````
M``````````````````````````````````````````@```````````!``@("
M``$```````````$``````````2@```````#V!P"R````````````````````
M```````P,`(```````$H````````````````````````````````````````
M,#`"```````!*````````````````````````````````````````#`P`@``
M`````2@````````$``"R```````````````````````````P,`(```````$H
M````````/``!L@``````````````````````````,#`"```````!*```````
M`/P/__(``````````````````````````#`P`@```````2@```````#\_W^S
M```````````````````````````P,`(```````$H````````<``_L@``````
M````````````````````,#`"```````!*````````(0``+(`````````````
M`````````````#`P`@```````2@`````````````````````````````````
M```````P,`(```````$H````````````L```````````````````````````
M,#`"```````$````%`````,```!'3E4`_AYLHJ!(W/^UQ9J%A4$8EVW**[T$
M````$`````$```!'3E4```````,````"```````````````!`````````#4#
M`````````0````````!%`P````````$`````````50,````````!````````
M`%\#````````#`````````#(&@````````T`````````$&8````````9````
M`````/"O`0``````&P`````````(`````````!H`````````^*\!```````<
M``````````@`````````!`````````#X!@````````4``````````!0`````
M```&`````````"@*````````"@````````#R!`````````L`````````&```
M```````U``!P`````+BJ`0``````%0````````````````````,`````````
M0+`!```````1`````````'@:````````$@````````!0`````````!,`````
M````$``````````!``!P``````$`````````!0``<``````"``````````8`
M`'`````````````````*``!P`````!L`````````$0``<`````!I````````
M`!(``'``````'0`````````3``!P`````"0`````````'@`````````(````
M`````/O__V\``````0``"`````#^__]O`````,@9````````____;P`````#
M`````````/#__V\`````\A@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!A````:0``````````````
M$0```"L``````````````&0``````````````!<````N`````````"0```!G
M````&0`````````X````(P````0```!)````'@````H```!F````/@``````
M````````0````!H````F```````````````(````)0````\`````````````
M`"(```!&`````````&$`````````30````````!2````(0```!T````R````
M`````$0````3`````````%L````Q```````````````2````-````"P````G
M`````````````````````````"D``````````P``````````````3P```#D`
M``!<````-P```$$````[```````````````&````40```"\````<````(```
M`#`````U`````````"T````8```````````````4````%@`````````H````
M"0```"H```!+````0@```&@`````````````````````````````````````
M`````````&(````````````````````+``````````````!5````````````
M`````````````````````````````%,`````````$````#T`````````/P``
M`!L`````````/````#,`````````!P``````````````'P```$X````V````
M`````%```````````````%T```!?``````````X````5`````````#H`````
M````7@```$<```!C````10````````!7`````````$P`````````0P```%D`
M``````````````P```!(````5````````````````@````````!*````8```
M``````````````````````!8```````````````%```````````````-````
M5@```%H`````````````````````````````````````````````````````
M``````````````!E````````````````````````````````````````````
M`````````````````````````P`,`,@:``````````````````![!```(``5
M``"P`0`````````````````@!```$``9`$BS`0`````````````````F!```
M$@`-`&@K````````&``````````W!```$@`-`"`N````````+`````````!W
M`P``$@`-`"AB````````"``````````!````$P#Q_P$`````````````````
M``"'`P``$@`-`-!!````````,`,```````!$!```$@`-```U````````N```
M``````"=`P``$@`-`&`J````````!`$```````!2!```$@`-`%`N````````
M8`````````#F`P``$@`-`'A?``````````(```````!>!```$@`-`+@U````
M````2``````````4!```$@`-``!%````````G`$```````#I`@``$0`0`$!F
M````````!`````````!Y!```$``5``"P`0````````````````#;`P``$@`-
M`)!=````````Z`$```````"&!```$@`-``@J````````6`````````".!```
M$@`-`-`=``````````````````!G`P``$@`-`(!A````````J`````````"6
M!```$``5``"P`0````````````````"=!```$``9`$BS`0``````````````
M```(`P``(0````````````````````````"I!```$``-`!`;````````````
M``````#2`P``$@`-``A=````````B`````````"P!```$``9`(##`0``````
M```````````2````$0`6`#"P`0`````````````````'`P``$0``````````
M``````````````#]`P``$@`-`&@W````````:`H```````"U!```$``8`$BS
M`0````````````````#``P``$@`-```V````````9`$```````"S`P``$@`-
M`(`K````````G`(````````*!```$0`5`""P`0``````"`````````#P`P``
M$@`-`+`N````````3`8```````!:`@``$@`-`!`;````````M`(```````!W
M`@``$@```/!E```````````````````*`@``$@```.!E````````````````
M```X`@``$@```-!E``````````````````"D````$@```,!E````````````
M``````"S````$@```+!E``````````````````"^````$0``````````````
M``````````"S`0``$@```*!E```````````````````G`@``$@```)!E````
M``````````````"@`@``$@```(!E``````````````````"2`@``$@```'!E
M``````````````````#+````$@```&!E``````````````````#>````$@``
M`%!E```````````````````?`@``$@```$!E``````````````````!?`@``
M$@```#!E``````````````````"G`@``$@```"!E``````````````````"&
M`@``$@```!!E``````````````````#&`@``$@````!E````````````````
M``#S````$@```/!D``````````````````#7````$@```.!D````````````
M```````_`@``$@```-!D``````````````````"6````$@```,!D````````
M``````````"9`0``$@```+!D```````````````````O`@``$@```*!D````
M```````````````)`P``$0````````````````````````#7`@``$@```)!D
M```````````````````C`P``$0````````````````````````#_````$@``
M`(!D``````````````````!P!```$@```'!D```````````````````8`@``
M$@```&!D``````````````````"_`@``$@```%!D``````````````````"X
M`@``$@```$!D`````````````````````P``$0``````````````````````
M``!H`@``(@````````````````````````"N`@``$@```#!D````````````
M``````"'````$@```"!D```````````````````.`0``$@```!!D````````
M``````````!V````$@````````````````````````!F````$@``````````
M``````````````!8````$@````!D``````````````````#8`0``$@```/!C
M```````````````````?`0``(`````````````````````````#\`0``$@``
M`.!C``````````````````#>`@``$@```-!C```````````````````A````
M$@```,!C``````````````````!-````$@```+!C```````````````````Y
M`0``(`````````````````````````"Z`0``$@```*!C````````````````
M``"?`0``$@```)!C``````````````````!-`@``$@```(!C````````````
M``````!5`0``$@```'!C```````````````````1`@``$@```&!C````````
M``````````!C`0``$@```%!C``````````````````!$````$@```$!C````
M``````````````"_`0``$@```#!C```````````````````1`P``$@```"!C
M``````````````````!&`@``$@```!!C``````````````````!\`@``$@``
M``!C``````````````````#X`@``$@```/!B``````````````````!S`0``
M(@`````````````````````````Q````$@````````````````````````#N
M`0``$@```.!B```````````````````F````$@```-!B````````````````
M``#@`0``$@```,!B``````````````````""`0``$0``````````````````
M``````"-`0``$@```+!B```````````````````<````$@```*!B````````
M``````````",`@``$@```)!B```````````````````#`@``$@```(!B````
M``````````````#'`0``$@```'!B````````````````````7T193D%-24-?
M3$E.2TE.1P!?7U),1%]-05``<&5R;%]F<F5E`'!E<FQ?<&%R<V4`4&5R;%]A
M=&9O<FM?=6YL;V-K`'!E<FQ?<G5N`'!E<FQ?86QL;V,`4&5R;%]S>7-?=&5R
M;0!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!P97)L7V1E<W1R=6-T`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%,`
M4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-V7W-E='!V;@!097)L7VYE=UA3
M7V9L86=S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`%]?9VUO;E]S=&%R=%]?`%!,7W1H<E]K97D`4&5R;%]G971?<W8`8VQO<V4`
M<'1H<F5A9%]G971S<&5C:69I8P!O<&5N-C0`<F5A9`!L<V5E:S8T`%]?97)R
M;F]?;&]C871I;VX`;W!E;F1I<@!?7W-T<FYC<'E?8VAK`%]?9G!R:6YT9E]C
M:&L`86-C97-S`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E
M`'-T<FYC;7``8VQO<V5D:7(`<W1R9'5P`'-T<G-T<@!S=')C:'(`7U]L:6)C
M7W-T87)T7VUA:6X`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`97AI=`!?7WAS
M=&%T-C0`<FUD:7(`;6MD:7(`7U]S<')I;G1F7V-H:P!M96UC:'(`<W1R=&]K
M`')E861D:7(V-`!M96UC<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T
M=6ED`%]?;'AS=&%T-C0`7TE/7W-T9&EN7W5S960`<F5A;&QO8P!S=&1E<G(`
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD
M+G-O+C$`7U]L:6)C7V-S=5]I;FET`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E
M<FYA;'-?4$%27T)/3U0`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]F:6YD
M<')O9P!P87)?<V5T=7!?;&EB<&%T:`!S:&%?:6YI=`!S:&%?=7!D871E`'-H
M85]F:6YA;`!P87)?:6YI=%]E;G8`<&%R7VUK=&UP9&ER`&UY7W!A<E]P;`!P
M87)?8VQE86YU<`!?9F)S<P!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M
M90!P87)?96YV7V-L96%N`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?<W1A<G0`7V9D871A
M`%]?8G-S7W-T87)T`%]F=&5X=`!?96YD`%]E9&%T80!'3$E"0U\R+C0`1TQ)
M0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,RXT`$=,24)#7S(N,```````
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``P`!
M``$``0`!``,``0`!``$``0`!``$``0`#``,``P`````````'``,``P`$````
M```#``,``P`#``D````#``,````"``,``P`#``@````#``,``P`#``,`!0`%
M```````````````#`````P`%``,```````(``@`#`````P``````!P`&``,`
M!0`#```````$````!``````````#``,``@```````0`!`%\#```0````(```
M`!1I:0T```@`O`0````````!``4`50,``!````!@````%&EI#0``"0"\!```
M$````'(9:0D```8`Q@0``!`````2:6D-```%`-($```0````=!EI"0``!`#<
M!```$````!!I:0T```,`Z`0````````!``(`10,``!``````````$FEI#0``
M!P#2!```$````!!I:0T```(`Z`0`````````````````````````````\*\!
M```````````````2`_BO`0``````````````$@,@L`$``````````````!(#
M0+,!```````````````2`_#_O6<``+S_`@`</"W@F0,(`+__:!6<9[B"@M\$
M`$`0`````+B"F=\)^"`#``````@`O]\``+S?"`#@`Q``O6<``````````)#_
MO6=@`+S_`@`</"W@F0,@%9QG.`"Q_["!D=\`@9G?:`"__U@`M?]0`+3_2`"S
M_T``LO\P`+#_)1B`````(MX0`*7_"`"F_Q``I6<(`*9G'`"D9QP`HZ\H`*+_
M"?@@`P````#`@H;?"(*$WZB`F=^K$1$$)2C``!"!@M\``$*080!`$$B"F=\X
M@)#?X(*2WV""F=\)^"`#``!$C@``1([J!$.08(*9WP(`8S0)^"`#Z@1#H!P`
MIH_J!$.0!`#$)#B!F=\!`&,T^"`$``,`QB3J!$.@"?@@`P``IO\0`*7?)3A`
M`#B`@M^P@(/?<,-'_%"`@M\``*G<^&E"9!P`J(\(`.+\4(""WP``9-P`:D)D
M`@`#*0``IM\``.G\$`#D_%P`8!08`.+\`P`))0@`I60#``@E!``$)```HMSX
M&`0`+1CC``$`A"0``&+\^O\$%0@`I60E$"`!^!`"`%"`A=_0@IG?>,,$WBT0
MX@`E0```:"FE9`GX(`,``$#\+P!`$"600`"(@9G?>,,$WE"`D]\)^"`#)`"T
M9U"`A-]0'W-F)2B``B7(8`*E`!$$,&>$9"<`0!`X@)7?\(*9WPGX(`-XPP3>
M&(*9WPGX(`,`````*`"CWP``(MXS`&(4:`"_WV``O-]8`+7?4`"TWT@`L]\X
M`+'?,`"PWR400`)``++?"`#@`W``O6<)^"`#.("0WR4@0``A`$`0>,,"_OB!
MF=\)^"`#X(*2WV""F=\)^"`#``!$CI;_`!"9"D"@B(*9WPGX(`-XPP3>SO\`
M$"600`!HPZ3>!0"`$+B`F=_D"1$$`````-7_`!#P@IG?4("$WR4H@`(ER&`"
M<0`1!,!FA&0E($``S/]`$&C#HO[S_P`0N("9W['_`!`@``(DZ("9WPGX(`,!
M``0D:(&9WPGX(`,`````````````````````)0#@`P$`$00`````)<B``P(`
M'#Q4$IPG+>"?`R7X```@@(3?``"EWP@`IF?P_P$D).BA`RB`A]\P@(C?)4A`
M`"50H`-H@IG?"?@@`P````#__P`0`````````````````@`#/"T8>0``$F-D
M.(!DW$"`8MPXL(1D!0!$$%"">=P#`"`3``````@`(`,`````"`#@`P`````"
M``,\+1AY`,@18V0X@&3<0(!EW#BPA&0O**0`^Q`%`/XO!0`M**(`>R@%``4`
MH!`H@GG<`P`@$P`````(`"`#``````@`X`,``````````.#_O6<0`+S_`@`<
M/"W@F0-X$9QG"`"P_SB`D-\8`+__4+,"D@P`0!3H@8+?!`!`$$B`@M_H@9G?
M"?@@`P``1-Q0@)G?,!XY9\O_$00``````0`")%"S`J(8`+_?$`"\WP@`L-\(
M`.`#(`"]9P`````"``(\+1!9``@10F10@%G<:!XY9\K_`!``````````````
M````````L/^]9T``O/\"`!P\+>"9`T@`O_\X`+;_,`"U_R@`M/\@`+/_&`"R
M_Q``L?\(`+#_00"`$.`0G&>@@8+?``!4W#T`@!(EJ(````""@"68H``ED(``
M10!`$#T``R0$`$,0``````$`0H+\_T`4`0!29B^050(`D!(```"0W@\``!(E
MB(`"/0`6)""!F=\E(``")3!``@GX(`,E**`"!`!`%"T8$@(``&*`$0!6$```
M```(`##>]/\`%@@`,69(`+_?0`"\WS@`MM\P`+7?*`"TWR``L]\8`++?$`"Q
MWR40``((`+#?"`#@`U``O6<`````+X@T`ON($0```'&N2`"_WP$`4F8M@!("
M0`"\WS@`MM\P`+7?*`"TWR``L]\8`++?$`"QWR40``((`+#?"`#@`U``O6<`
M````2`"_WR6```!``+S?.`"VWS``M=\H`+3?(`"SWQ@`LM\0`+'?)1```@@`
ML-\(`.`#4`"]9\+_`!`ED````````-#^O6<@`;S_`@`</"W@F0-H#YQG\`"R
M_["!DM\H`;__&`&W_Q`!MO\(`;7_``&T__@`L__H`+'_X`"P_P``0M[8`*+_
M!`"`$````````(*`$0!`%"6`@`#8`*/?``!"WFL`8A0H`;_?(`&\WQ@!M]\0
M`;;?"`&UWP`!M-_X`+/?\`"RW^@`L=_@`+#?"`#@`S`!O6<`````((*9WPGX
M(`,`````[/]`$"6(0`!0@)/?4("4WTAF<V8EJ*`#R""49O"!F=\)^"`#)2`@
M`CX`0!"8@9G?$P!#D-+_8R0"`&`4$P!69`$`PY+V_V`0\(&9WQ,`0I#2_T(D
M!0!`%``````!`,*2TO]")#<`0!``````[/]`$/"!F=_0@9G?"?@@`R4@``+0
M@9G?)2#``@GX(`,EN$``>(&9WRT0X@(`(`(`"?@@`P(`A"0P@9G?)2!``"5(
MP`(E0``")3A@`O__!B0!``4D"?@@`R6X0`"H@IG?)3"@`B4HX`()^"`#`P`$
M)/__`R0%`&(0(`"BCP!``R0`\$(P&@!#$"7(@`+(@9G?"?@@`R4@X`)`@IG?
M"?@@`R4@X`+P@9G?"?@@`R4@(`+$_T`4F(&9WPGX(`,E("`"8(&9WPGX(`,E
M(``"GO\`$````````````@#"DK3_0!#0@9G?R?\`$```````````?_\1!"4@
MX`+H_P`00(*9WVB!F=\)^"`#````````````_[UG\`"\_P(`'#PMX)D#2`V<
M9^@`L?^P@9'?X`"P_SB"F=_X`+__```BWB4H@``E@(``)3"@`P,`!"38`*+_
M"?@@`P`````/`$`4(`"CCP!`!"0`\&,P!`!D$"4H8```H`,T"0"C%``````P
M@IG?`@`%)`GX(`,E(``"`P``$`$`0BP`````)1```-@`I-\``"/>!@"#%/@`
MO]_P`+S?Z`"QW^``L-\(`.`#``&]9VB!F=\)^"`#``````````#@_[UG$`"\
M_P(`'#PMX)D#B`R<9]"!F=\``+#_&`"__P@`L?\)^"`#)8"``/__1F0M,`8"
M*Q`&`@4`0!0O``,D-```$``````U``82````````PH#\_T,0___&9`$`QF0K
M$`8"*P!`$"\``R3__\9D*P`&$@```````,*`_/]#%/__QF0!`,9D!```$"\`
M`R0``,*`!0!#%`````#__\9D*Q`&`OK_0!0`````+S#0``(`PF0!$$(L#P!`
M$#B`D=_8@IG?)2@``F"S)&8`$`<D"?@@`P$`QF08`+_?$`"\WP``L-]@LR)F
M"`"QWP@`X`,@`+UG`````!@`O]\0`+S?"`"QWP``L-\E$```"`#@`R``O6?A
M_P86+P`#)`````````."+P`")`H`8A#X@)G?4("$WPGX(`-89H1D&`"_WQ``
MO-\(`+'?``"PWP@`X`,@`+UG4("$WPGX(`-09H1D&`"_WQ``O-\(`+'?``"P
MWP@`X`,@`+UGL.^]9T`0O/\"`!P\+>"9`Q`+G&<P$+3_&!"Q_["!E-\EB(``
M4("$WR@0L_\@$++_4(&9WT@0O_\X$+7_$!"P_P@`LV<``(+>)9"@`/\/!B0E
M*&`"8&:$9`@0HO\)^"`#```````0`@`W`$`8__]0)!`0HV<M&'``X(*$W_CO
M8X`?`&`4``"5C"4``!(H@9G?)3```B\`!20)^"`#)2!@`B``0!!@@IG?"?@@
M`R4@H`*X@9G?)3@``B4P8`(E*"`""?@@`R4@0``($*/?``""WBD`8A1($+_?
M0!"\WS@0M=\P$+3?*!"SWR`0LM\8$+'?$!"PWP@`X`-0$+UG`````"B!F=\E
M@$``)3```B\`!20)^"`#)2!@`N/_0!1@@IG?8(*9WPGX(`,E(*`"<(*9WR4P
M0`(E*"`""?@@`R4@0`#A_P`0`````.""@M]@@IG?``!5C`GX(`,E(*`"<(*9
MWR4P0`(E*"`""?@@`R4@0`#5_P`0`````&B!F=\)^"`#``````````"@_[UG
M4`"\_P(`'#PMX)D#B`F<9R``LO^P@9+?&`"Q_Q``L/]8`+__2`"W_T``MO\X
M`+7_,`"T_R@`L_\E@*`````#@@``1=X]``(D)8B```@`I?\"`&(4T(&9WP$`
M$&8)^"`#)2```E"`F=\$`*5G)2`@`E`?.6<+_A$$)9A``%D`0!`EH$``T(&9
MWPGX(`,E($``*Q!3`$,`0!`$`+:/H(&5W_BP%@```"*")1@@`@8`0!0]``0D
M>0``$"48```!`&*``P!`$`$`8V3\_T04`````"\8<0``&`,`>(&9WP(`9&8M
M((,`"?@@`P``L]XMF'8"'0!`$```8OX$`*./``"BWO@8`P`M$$,```!"W```
M(X(!`"1F``!#H`@`8!0]``8D7```$"4H0`````````"#@`$`A&0G`&`0``!#
MH"4H0`#Z_V84`0!"9#T``R0``*.@`````````X(!`$)D`0`09OS_8!3__T.@
M"`"CWP``0MY/`&(46`"_WU``O-](`+??0`"VWS@`M=\P`+3?*`"SWR``LM\8
M`+'?$`"PWP@`X`-@`+UG```"@@$`E&8!`!!F[?]`$/__@J(```*"`0"49@$`
M$&;W_T`4__^"HN;_`!```````@"C9"4H0`#:_P`0)1!@`*"!E=\``+?>``#B
MWBP`0!`E$.`"):````@`0]PE((`""`!"9/S_8!0!`)0F`P"$)/@@!``X@(+?
M8,-#C!0`8!2P@IG?>(&9WP$``R0)^"`#8,-#K,O_0!`E($``2(&9W_BP%``E
M,,`""?@@`R4HX`(E($````"B_@$`@B;X$`(`+2""````@/R-_P`0!`"TKR4H
M@``)^"`#)2#@`B4@0`"X_T`0``"B_O/_`!#XL!0`K/\`$`$`0F2/_P`0>(&9
MWQ``!"3;_P`0):```&B!F=\)^"`#`````.#_O6<0`+S_`@`</"W@F0/(!IQG
M"`"P_^""D-\8`+__8(*9WPGX(`,```2.8(*9WPGX(`,```2.6("'WU"`A=\0
M@H;?"(&9W[BEYV1P9J5D"?@@`R4@0`!@@IG?"?@@`P``!(Y0@(C?4("%WV"`
MAM\`@IG?\&D(925(```E.``!D&:E9`GX(`,E($``&`"_WQ``O-\(`+#?"`#@
M`R``O6?P_[UG``"\_P(`'#PMX)D#*`:<9^""@M\(`+__8(*9WPGX(`,``$2,
M6("'WU"`A=\0@H;?"(&9W[BEYV1P9J5D"?@@`R4@0``(`+_?``"\WP@`X`,0
M`+UGH-^]9U`@O/\"`!P\+>"9`]`%G&=`(++_L(&2WU@@O_\`@YG?2""S_S`@
ML/\X(+'_``!"WB`0LV<H(*+_"?@@`P````!0@(G?4("'WS"!F=\8`*1GJ&8I
M925`0`"P9N=D`1`&)`$`!20)^"`#"`"D_P@`I-]0@9G?`!`&)`GX(`,E*&`"
M`(`"`!D```9X@9G?`0`$)@GX(`,EB``""`!`$"4@0`#8@9G?)3```@GX(`,E
M*&`"+8A1`"4@0````""B*""CWP``0MX+`&(46""_WU`@O-]((+/?0""RWS@@
ML=\P(+#?)1"```@`X`-@(+UG\_\`$"4@``!H@9G?"?@@`P```````````@`#
M/"T8>0#(!&-D:(!YW+G_`!``````H.Z]9T@1O/\"`!P\+>"9`[`$G&<X$;;_
M$!&Q_["!EM\EB(``4("9WU"`A-]8$;__*!&T_P@1L/]0$;[_0!&W_S`1M?\@
M$;/_&!&R_P``P][`9H1D4!\Y9R6@H``<`*5G^!"C_]K\$00`````H(*9WR\`
M!20E("`""?@@`R6`0``9`$`0T(&9WU"`A-]0@)G?)2@@`J@F.6>C_A$$T&:$
M9"40(`+X$*3?``##WG@`@Q18$;_?4!&^WT@1O-]`$;??.!&VWS`1M=\H$;3?
M(!&SWQ@1LM\0$;'?"!&PWP@`X`-@$;UG`````"4@(`()^"`#4("2WUB!F=_@
M9D5F)2"``@GX(`,`F`(`W_]`$"6X0`!0@(+?4("4WU!F0F0(`*+_``#B@E"`
ME=\\`$`06&:49@8``!+P@)G?)2C@`@GX(`,E(``"+0!`$%B!F=_0@9G?"?@@
M`R4@X`(O``8D`"@"`/__HR0M(.,"``""@`H`1A0!`&(F`````"4H8`#__V,D
M``"`H"T@XP(``(*`^O]&$``````!`&(F(2A%```0I2BY_Z`0,(&9W_@`OF<E
M(,`#)5`@`B5(@`(E0.`"Z&:G9@`0!B0)^"`#`0`%)*B"F=\@`*9G)2C``PGX
M(`,#``0D!0!`%$``HH\`@`,T`/!",!<`0Q`P@IG?6(&9W^!F168)^"`#)2``
M`)__0!`EN$````#B@L;_0!0`````"```$@````````*2TO]")`(`0!0`````
M`0`"DO#_0!!8@9G?"`"WW]/_`!`!``4D``````$`!20)^"`#)2#``^?_0!18
M@9G?4("$WU"`F=\E*,`#J"8Y9RS^$0309H1D^("9WPGX(`,E(,`#AO\`$```
M``!H@9G?"?@@`P````````````"#@`<`8!`E$(````````$`A&0O`&4X``"#
M@/S_8!0*$(4`"`#@`P``````````\/^]9P``O/\"`!P\+>"9`P@`O_\*`(`0
MX`&<9P``@H`'`$`04("9WP@`O]\``+S?J",Y9TC]`!`0`+UG`````%"`A-_X
M@)G?"?@@`U!FA&0(`+_?``"\WP@`X`,0`+UG8/^]9X@`O/\"`!P\+>"9`X`!
MG&=8@(/?8`"S_["!D]^0I6)D:`"T_U@`LO]0`+'_2`"P_Y@`O_^0`+[_@`"W
M_W@`MO]P`+7_D*5FW`@`1=P0`$3<&`!#W```9]X@`$*44("0WU"`E-^@@9+?
M.`"G_Q``IO\8`*7_(`"D_R@`H_\P`**G#`"Q9U`?$&;P9I1F)2@@`B7(``(!
M_!$$)2"``A$`0!`,`*./``!"WO@8`P`M$$,`"`!#W/7_8!```$/\$`!#W`@`
M0F3]_V`4``!#_"4H(`(ER``"\?L1!"4@@`+Q_T`4#`"CCU"`E-^@@9+?`&>4
M9B4H(`(ER``"Z/L1!"4@@`(2`$`0#`"CCP``0M[X&`,`+1!#``@`0]SU_V`0
M``!#_``````0`$/<"`!"9/W_8!0``$/\)2@@`B7(``+7^Q$$)2"``O#_0!0,
M`*./4("4WZ"!DM\(9Y1F)2@@`B7(``+.^Q$$)2"``A(`0!`,`*./``!"WO@8
M`P`M$$,`"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`")<@`
M`KW[$00E((`"\/]`%`P`HX]0@)3?H(&2WQAGE&8E*"`")<@``K3[$00E((`"
M$@!`$`P`HX\``$+>^!@#`"T00P`(`$/<]?]@$```0_P`````$`!#W`@`0F3]
M_V`4``!#_"4H(`(ER``"H_L1!"4@@`+P_T`4#`"CCU"`E-^@@9+?(&>59B4H
M(`(ER``"FOL1!"4@H`(2`$`0#`"CCP``0M[X&`,`+1!#``@`0]SU_V`0``!#
M_``````0`$/<"`!"9/W_8!0``$/\)2@@`B7(``*)^Q$$)2"@`O#_0!0,`*./
M4("5WZ"!DM\P9[5F)2@@`B7(``*`^Q$$)2"@`A(`0!`,`*./``!"WO@8`P`M
M$$,`"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`")<@``F_[
M$00E(*`"\/]`%`P`HX]0@)7?H(&2W\!FMF8E*"`")<@``F;[$00E(,`"$P!`
M$%"`E]\,`*./``!"WO@8`P`M$$,`"`!#W/3_8!```$/\$`!#W`@`0F3]_V`4
M``!#_"4H(`(ER``"5?L1!"4@P`+Q_T`4#`"CCU"`E]^@@9+?0&?V9B4H(`(E
MR``"3/L1!"4@P`(2`$`0#`"CCP``0M[X&`,`+1!#``@`0]SU_V`0``!#_```
M```0`$/<"`!"9/W_8!0``$/\)2@@`B7(``([^Q$$)2#``O#_0!0,`*./4("6
MWZ"!DM]09]YF)2@@`B7(``(R^Q$$)2#``Q(`0!`,`*./``!"WO@8`P`M$$,`
M"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`")<@``B'[$00E
M(,`#\/]`%`P`HX]0@)[?H(&2WV!GWF<E*"`")<@``AC[$00E(,`#$@!`$`P`
MHX\``$+>^!@#`"T00P`(`$/<]?]@$```0_P`````$`!#W`@`0F3]_V`4``!#
M_"4H(`(ER``"!_L1!"4@P`/P_T`4#`"CCU"`GM^@@9+?T&;>9R4H(`(ER``"
M_OH1!"4@P`,2`$`0#`"CCP``0M[X&`,`+1!#``@`0]SU_V`0``!#_``````0
M`$/<"`!"9/W_8!0``$/\)2@@`B7(``+M^A$$)2#``_#_0!0,`*./4("$WR4H
M(`(ER``"YOH1!'!GA&0P`$`0)2A``%"`DM^H)E)F)<A``K7\$0109\1F4("$
MWR4H(`(ER``"VOH1!(AGA&0%`$`0)2A``%"`A-\ER$`"JOP1!*!GA&10@(3?
M)2@@`B7(``+/^A$$L&>$9!P`0!`E*$``)<A``J#\$03`9J1F4("%WR!GA&8E
MR$`"F_P1!.AGI60X`*/?``!BWBD`8A28`+_?D`"^WX@`O-^``+??>`"VWW``
MM=]H`+3?8`"SWU@`LM]0`+'?2`"PWP@`X`.@`+UG4("2W]3_`!"H)E)F4("$
MWR4H(`(ER``"K?H1!,!GA&0&`$`0)2A``"7(0`)^_!$$0&?D9M[_`!!0@(7?
M4("%WR"!F=\*``8DV&>E9`GX(`,A`*1GU?]`%"L`I6<ER$`"<?P1!$!GY&;1
M_P`04("%WVB!F=\)^"`#``````````#0_[UG(`"\_P(`'#PMX)D#,/N<9Q@`
ML?\0`+#_.("1W["!D-\H`+__```$WA"P(H[__P,D"`"D_PL`0Q!0@(3?"`"D
MWP```]X8`(,4*`"_WR``O-\8`+'?$`"PWP@`X`,P`+UG`````%"`F=\$`*5G
M4!\Y9W;Z$01`9X1D"`!`$````````$*`!0!`$``````P`$(X*Q`"`.G_`!`0
ML"*N)1```.;_`!`0L"*N:(&9WPGX(`,`````\/^]9P``O/\"`!P\+>"9`WCZ
MG&>H@9G?"`"__PGX(`,`````P(&9WPGX(`,E($```@!`$`@`O]\``$+<``"\
MWP@`X`,0`+UGL/^]9T``O/\"`!P\+>"9`S#ZG&<P`+/_*`"R_U"`D]^P@9+?
M4("9WR``L?](`+__.`"T_Q@`L/\``$+>)8B```0`I6?P9V1F4!\Y9P@`HO\_
M^A$$`````!4`0!`E@$````!"@!(`0!"`@9G?)2@@`@GX(`,E(``"'0!`$-"!
MF=\(`*/?``!"WC,`8A1(`+_?0`"\WS@`M-\P`+/?*`"RWR``L=\8`+#?"`#@
M`U``O6<(`*/?``!"WB<`8A0E*"`"4("9WT@`O]]``+S?.`"TWR@`LM\@`+'?
M&`"PW_!G9&8P`+/?J"8Y9^_[`!!0`+UG"?@@`R4@(`+0@9G?)2```@GX(`,E
MH$``>(&9WRT0@@()^"`#`@!$9%"`B=]0@(??,(&9WP$`!20E4``"X&8I925`
M(`+H9N=D__\&)"4@0``)^"`#):!```@`H]\``$+>V_]B$"4H@`)H@9G?"?@@
M`P``````````$("]9]A_O/\"`!P\+>"9`\CXG&?@?[[_P'^U_[A_M/_H?[__
MT'^W_\A_MO^P?[/_J'^R_Z!_L?^8?[#_4("#W^#]O6<0`*=G__\"/"6H@`"@
M@00T)3!@`"T@AP!T?D5D+2B%`+"!GM_`9L1DH($&-"TPQP`M$,(`$`"C_YB!
M!C0``,/?+3#'````P_Q0@(/?4("4WQ!H8V1X?D/\4("#WU`?E&909F-D@'Y#
M_%"`@]\ER(`"&&AC9+!^0_Q0@(/?B'Y`_"!H8V2X?D/\4("#W]!^0/PH:&-D
MP'Y#_%"`@]^@?D#\,&AC9,A^0_Q0@(/?.&AC9+SY$028?D/\!`!`$*B!F=\`
M`$.`@P%@%"4@0``)^"`#`````,"!F=\)^"`#)2!``$0!0!#__Q$\``!0W$,!
M`!(0`*-GT(&9WPGX(`,E(``">(&9WW@@`@`)^"`#`0"$9```"((0```1)8A`
M`%"`A]\ED"`"2&CS9``````P@9G?_P`(,24@0`(E.&`"__\&)`$`!20)^"`#
M`0`09@``"(+V_P`5`@!29O__$SP0`*-GH($"-*A^=F8M$$,`4("$WU"`DM\M
ML%8`H($"-'1^<V8M$$,`H&>$9"V84P`$```0Z")29@@`Q-YF`(`0"`#69B7(
M@`)_^1$$)2A@`OG_0!`E@$````!"@/;_0!`ER$`"7OH1!"4@``+R_T`0^("9
MWPGX(`,E(``"5@!`$"6`0```````T(&9WR4@``()^"`#4("3W]"!F=\E("`"
M"?@@`R6P0`!X@9G?+;#"`@"P%@`$!,0F"?@@`R6P@`!0@(K?4("'WS"!F=\E
M($``)5@@`E!H2F589FEF)4```EAHYV3__P8D`0`%)`GX(`,ED$``^(*9W\`!
M!20)^"`#)2!``O__`R0'`&(4"(.9WPGX(`,`````$0`#)```28P*`2,5X(&"
MWQ``HV?__Q$\H($"-#B"F=\M$$,`V'XF9BTP1@`E*$`""?@@`P,`!"1#`$`0
M)8!``."!@M]0@(;?R(*9WP``I]X``$3<)4!``JAHQF0!``4D"?@@`R6(```0
M`*-GF($"-"T00P```$/<``#"W\D!8A0E$"`"(`*]9^A_O]_@?[[?V'^\W]!_
MM]_(?[;?P'^UW[A_M-^P?[/?J'^RWYA_L-^@?['?"`#@`_!_O6<`````H($"
M-!``HV=0@);?__\3/"T00P`MF%,`>'YPWB60```%```0Z"+69BT08@)X?E#<
M$P``$@````````*"$`!`$"7(P`(E(``"[_D1!`$`4B;U_T`0^!`2`/B`F=\)
M^"`#)2```I+_0!0E@$``^!`2`"T08@)X?E#<[_\`%@````"+_P`0)8```!``
MHV>@@0(T+1!#`"VX40#X?N*.`$`#)`#P0C"W_T,4X(&"WZB!F=\(?^.."?@@
M`Q@`H_\8`*/?`!`"`*__8A3@@8+?^'[BCL`!`R3_`4(PJO]#%."!@M]X@9G?
M"?@@`R4@P`(0`*1GH($#-"T89`!0@(3?='XE9@!IA&0M*&4`)<B``MCX$00E
MB$``+`%`$"4@0`#X@)G?"?@@`P``MMYP@)G?)2A``-O[$00E(,`"(P%`$"6X
M0`#0@9G?"?@@`R4@X`(`&`(`!`!B*!``0!0EL&``4("%W_"`F=_\_\1F"&FE
M9`GX(`,M(.0""`!`%`0``B0F`<(2^__#)BT8XP(``&.`+P`")"$!8A``````
M.("5W___`R00L**."@%#$!``HV>'`$`0&(&9WU"`EM]0@(+?4("%WT!GQ&:H
M)EEDZ&>E9'[Z$008`+G_`(.9WU"`E-\)^"`#__\5)%"`A]_P:9=F,(&9WU"`
ME-\E6.`")5!``%AF:68E0$`"*&GG9/__!B0!``4D)2`@`@GX(`,1`!8D%```
M$#AIE&8`````"?@@`P```````$*,%`!6%`"#F=\)^"`#`0`0)C"!F=\E6``"
M)5!``%AF:68E0$`")3B``O__!B0!``4D)2`@`@GX(`,``+?_^(*9W\`!!20)
M^"`#)2`@`NG_HA((@YG?0(*9WPGX(`,E($`"$`"BWQ@`N=_`9D1D"?@@`R4H
M(`)X@)G?'/X1!"4@(`(]_P`0$`"C9P`````0`*-G`````*"!`C1T?C)F+1!#
M`%"`A-\MD%(`H($"-"T00P`EF````&B$9`<``!`MB%$``````/@0$P`M$"("
MD'Y$W!0`@!!X@9G?)2A``B7(@`)6^!$$`0!S)O;_0!````````!#@//_8!#X
M@)G?"?@@`R4@0`"A_D`4)8!``/@0$P`M$"("D'Y$W/#_@!0E*$`">(&9WPT`
M!"0)^"`#4("0WPAH$&8EB$``GOX`$%,`""10@(;?R(*9WP``I]X``$3<)4!`
M`FAHQF0!``4D"?@@`R6(```$_P`0$`"C9WB`F=_>_1$$$`"B_Q``HM_X@)G?
M"?@@`R4@0`#Z_@`0)8A``!"PH*X8@9G?)2@```GX(`,E(.`"=O]`$"6@0`"0
M@IG?)2!```(`!B3N_P4D"?@@`___$#P0`*-GH($"-"T00P#X?Q5F+:A5`%B"
MF=\&``8D)2B@`@GX(`,E((`"$`"C9Z"!`C0M$$,`+1!0`/A_0Y`%`&`4D(*9
MW_E_0Y!#``0D@P!D$``````E,```)2@``"4@@`()^"`#__\0/("`F=]P!Q$$
M^'\69A``HV<EJ$``H($"-"T00P`%```0+;!6```````E*,`"B`<1!"4@H`)8
M@IG?`(`&-"4HP`()^"`#)2"``@`P`@#V_\`<B("9WY"!F=\E((`""?@@`[!_
M$&80`*-GH($"-"T00P`MH%``D("9WR4HH`(E((`"[0<1!!@`$&:@@0(T$`"C
M9U"`A]\M$$,`+8!0`"@`%69(:/9D````````B)(P@9G?)2```B4XP`+__P8D
M`0`%)`GX(`,"`!!F]_^P%@$`E&80`*1GH($#-"T89`#__P(\R']*9%"`B]\M
M$&(`4("'WZ"!`S0M&&0`,(&9W_!I:V4M4&H`6&9I9B5`0`(8:>=D__\&)`$`
M!20E("`"\']`H`GX(`,`````4(""WT""F=\E($`"J"9"9`GX(`,8`*+_$`"B
MWQ@`N=_`9D1D"?@@`R4H(`)X@)G?6?T1!"4@(`)Z_@`0$`"C9]W^`!```+?>
M4("6W___!3R@@0(T+1!#`'1^I60M*$4`)<B``J#W$01`9\1F<_]`$```````
M`$*`</]`$#```R1N_T,0`0`").G^`!`0L**N"`"UWM[^H!+0@9G?"?@@`R4@
MH`($`$,LV?Y@%%"`A=_P@)G?_/]"9!!II60)^"`#+2"B`M+^`!`*N*("^G]%
MD$$`!"1[_Z04D(*9W_M_1)!Y_X,4)3```/Q_1)!(``,D=?^#%`````#]?T.0
M10`")''_8A0`````)2"``@(`!B0)^"`#QO\%)%B"F=\E**`")2"``@GX(`,I
M``8D4("+WU"`A]_P:6ME,(&9WR50H`)89FEF)4!``AAIYV3__P8D`0`%)*C_
M`!`E("`":(&9WPGX(`,`````L/^]9T``O/\"`!P\+>"9`V#NG&<0`+#_X(*0
MWT@`O_\P`+3_*`"S_Q@`L?\X`+7_(`"R_["!D]]@@IG?```$C@``8MX$`+1G
M"`"B_PGX(`,````````$CF""F=\)^"`#)8A``+@`(Y)0@)'?4("$WU`?,68E
M*(`"(&>$9"7((`(_]Q$$N0!#H`0`0!`Q``,D``!$@(``@Q``````F("9WP_[
M$00`````8(*9WPGX(`,```2.4("%WX""F=\#``<D`0`&)%!II60)^"`#)2!`
M`!$`0!`ED$``8(*9WPGX(`,```2.$`!#WE"`AM\``&7<<(*9WR4@0``)^"`#
M6&G&9!``0MX``$+<#`!"C(`%0GQS`$`48(*9WV""F=\)^"`#```$CE"`A=^`
M@IG?`P`')`$`!B1@::5D"?@@`R4@0``2`$`0)9!``%"`A-\ER"`"T&:$9`KW
M$00E*(`"```$CF""F=]2`$`0):A```GX(`,`````$`!#WG""F=\``&7<)3"@
M`@GX(`,E($`````$CF""F=\)^"`#.("5WP``!(Y@@IG?"?@@`R600`!0@(7?
MZ(*9WR4@0``!``8D"?@@`VAII610@(;?<(*9WR4H0`"`:<9D"?@@`R4@0`)@
M@IG?"?@@`P``!(Y0@(3?)2B``L!FA&0ER"`"X?81!+D`0*`E@$``&`!`$&C#
MHO[X@IG?P`$%)`GX(`,E(``"$0`#)`0`0Q`!`$,D`@!C+#4`8!`X@(/?"`"C
MWP``8MXY`&(42`"_WT``O-\X`+7?,`"TWR@`L]\@`++?&`"QWQ``L-\(`.`#
M4`"]9SB`@M^@@)G?R?P1!'##1-PE@$``X_]`%&C#HOY0@(3?0(&9WPGX(`.(
M:81D``````$`0H""_T`0F("9WW[_`!````````````GX(`,`````.("#WQ``
M0MYPPV/<4("9WP``9=P@)3EG'_@1!```1-RM_P`0```$C@GX(`,```2.$`!#
MWG"!F=\``&7<"?@@`R4@0`"'_P`08(*9WU"`A-]PPV/<0(&9WP``9=PE.$``
M)3```@GX(`.P:81D:(&9WPGX(`,`````P/^]9S``O/\"`!P\+>"9`S#KG&<H
M`+/_L(&3WQ@`L?\X`+__(`"R_Q``L/\``&+>)8B```@`HO\I`(`0````````
M@H`F`$`04("9WZ@C.6>5]Q$$````````0X`'`&`0)8!````````!`$)D+P!E
M.```0X#\_V`4"H!%`#B`DM___P,D$+!"CAL`0Q!0@(3?!P!`$``````%`"`2
M````````(H(B`$`4((&9WP`````(`*/?``!BWC4`8A0X`+_?,`"\WR@`L]\@
M`++?&`"QWQ``L-\(`.`#0`"]9P````!0@(3?^("9WPGX(`-09H1DVO\`$```
M0X!0@)G?!`"E9U`?.6=2]A$$0&>$9!X`0!````````!"@!L`0!`P``,D&0!#
M$`$``B3;_P`0$+!"KE"`A=\$``8D4&BE9`GX(`,E(``"VO]`%``````(`*/?
M``!BW@X`8A10@)G?.`"_WS``O-\H`+/?(`"RWQ``L-\E("`"&`"QW\@@.6>2
M]@`00`"]9P````#)_P`0$+!`KFB!F=\)^"`#``````````!`_;UGL`*\_P(`
M'#PMX)D#D.F<9["!B=^X`K__J`*R_Z`"L?^8`K#_```BW0@`HV>(`J+_.`"(
M9'@`C60E4&``_P`,/`````````?=```%C3XP!P`^$@<`.%X&`#X^!P``_T(P
M)1!'`*`H!7P#^&=].#(&``(L)0`E$$<`)##,``/XI7PE$$8`"``(90``1?T(
M`$+][/^H%1``2F4``FAD:`!BW$``9]P0`&;<``!EW"801P`F$$8`)A!%`'@H
M`@#Z%P(`)1"B``/X0GR``&+\"`!C9/+_:!0(`*[?``"+W!``AMP8`(?<"`"(
MW():##R9>8QE(`"*W/H>"P!X$0L`)1!#`"UPS`$F&,<`N&\(`+HH"``E**4!
M+7#*`0/X0GPD&&@``_BM?"889P`M$$X`$`"NWRT00P`F&,T``_A"?"08:P`M
M<,P!+7#'`7C!`@#ZS@(`)AAF`+B'"P"Z>`L`+1AN`"5P&0,E>`\"+1AN`!@`
MKM\F**\``_AC?"0HH@`M<,P!)BBM`"UPQ@%XR0,`^H8#`+C'`@"Z$`(`)<`"
M`RT0K@`E*#`#(`"NWRT010`F*/@!`_A"?`/X[WTM<,P!)"BC`"UHS0%XR0(`
M^H8"`"8HKP"X=P,`NA@#`"5PPP$M**T`)1@P`R@`K=\M**,`)A@.`P/XI7P#
M^!A_)!AB`"UHK`$M:*\!>,D%`/J&!0`F&'@`N'\"`+H0`@`E>.(!+1AM`"40
M,`,M&&(``_AM?#``H]\F$,\!)!!%``/XSGTM&&P`+1AX`'C)#0#ZA@T`)A!.
M`"T00P`E&#`#+1!#`+C'!0"Z*`4`)<`%`P/X17PX`*+?)ACX`208;0`#^.]]
M+1!,`"T03@!XR04`^H8%`"88;P`M&&(`)1`P`RT88@"X=PT`NF@-`"5PS0$#
M^&U\0`"CWR80#@,D$$4``_@8?RT8;``M&&\`>,D-`/J&#0`F$%@`+1!#`"48
M,`,M$$,`N'\%`+HH!0`E>.4!`_A%?$@`HM\F&,\!)!AM``/XSGTM$$P`+1!8
M`'C)!0#ZA@4`)AAN`"T88@`E$#`#+1AB`+C'#0"Z:`T`)<`-`P/X;7Q0`*/?
M)A#X`20010`#^.]]+1AL`"T8;@!XR0T`^H8-`"803P`M$$,`)1@P`RT00P"X
M=P4`NB@%`"5PQ0$#^$5\6`"BWR88#@,D&&T``_@8?RT03``M$$\`>,D%`/J&
M!0`F&'@`+1AB`"40,`,M&&(`N'\-`+IH#0`E>.T!`_AM?&``H]\F$,\!)!!%
M``/XSGTM&&P`+1AX`'C)#0#ZA@T`)A!.`"T00P`E&#`#+1!#`+C'!0"Z*`4`
M)<`%`P/X17QH`*+?)ACX`208;0`#^.]]+1!,`"T03@!XR04`^H8%`"88;P`M
M&&(`)1`P`RT88@"X=PT`NF@-`"5PS0$#^&U\<`"CWR80#@,D$$4``_@8?RT8
M;``M&&\`>,D-`/J&#0`F$%@`+1!#`"48,`,M$$,`N'\%`+HH!0`E>.4!`_A%
M?'@`HM\F&,\!)!AM``/XSGTM$$P`+1!8`'C)!0#ZA@4`)AAN`"T88@`E$#`#
M+1AB`+C'#0"Z:`T`)<`-`P/X;7R``*/?)A#X`20010`#^.]]+1AL`"T8;@!X
MR0T`^H8-`"803P`M$$,`)1@P`RT00P"X=P4`NB@%`"5PQ0$#^$5\B`"BWR88
M#@,D&&T``_@8?RT03``M$$\`>,D%`/J&!0`F&'@`N'\-`+IH#0`E>.T!+1AB
M`)``K=\E$#`#+1AB`"80SP$#^&-\+6BL`0/XSGTD$$4`+<"X`?K.`P!X:0,`
M)A!.`"T06``EP+D!N&\%`+HH!0`E:*4!F`"YWRT06``#^$)\)BCM`2W(+`/Z
MA@(``_CO?20HHP!XP0(`+7`N`R8HKP`EP!`#+2BN``/X&'^X=P,`NA@#`"TH
MN``E<,,!H`"XWR88K@$M8`P#`_BM?2088@`#^+E\+7B/`288;0#ZAAD`+1AO
M`'C!&0"X?P(`NA`"`"5XX@$EP!`#)A#/`0/X&'\MP'@`)A!%`-EN`SRH`*7?
MH>MC-`/X$'\M**,`^HX0`'AA$``M:*T`)6"1`0/X0GPM$$T``_B,?;AO&0"Z
MR!D`)6BY`2U@3`"P`*+?`_B9?28H[0$FP+@`^HX9`"T00P`#^,Y]>"D9`"T0
M3@`E*+$``_@.?RT03@`#^*5\N'<0`+J`$``E<-`!+2A%`+@`HM\#^+A\)H"N
M`0/X\7TM$$,`)G@,`OJ&&`!X81@`+1!1``/X[WTE8)`!+1!/``/XC'VX?QD`
MNL@9`"5X^0$M8$P`P`"BWP/XF7TF@,\!`_BQ?2T00P`F:`4"^H89`'@I&0`M
M$%$``_BM?24HL``M$$T``_BE?+AO&`"ZP!@`)6BX`2TH10#(`*+?`_BX?":`
M[0$#^-%]+1!#`"9P#`+ZAA@`>&$8`"T040`#^,Y])6"0`2T03@`#^(Q]N'<9
M`+K(&0`E<-D!+6!,`-``HM\#^)E])H"N`0/X\7TM$$,`)G@%`OJ&&0!X*1D`
M+1!1``/X[WTE*+``+1!/``/XI7RX?Q@`NL`8`"5X^`$M*$4`V`"BWP/XN'PF
M@,\!`_BQ?2T00P`F:`P"^H88`'AA&``M$%$``_BM?25@D`$M$$T``_B,?;AO
M&0"ZR!D`)6BY`2U@3`#@`*+?`_B9?2:`[0$#^-%]+1!#`"9P!0+ZAAD`>"D9
M`"T040`#^,Y])2BP`"T03@`#^*5\N'<8`+K`&``E<-@!+2A%`.@`HM\#^+A\
M)H"N`0/X\7TM$$,`)G@,`OJ&&`!X81@`+1!1``/X[WTE8)`!+1!/``/XC'VX
M?QD`NL@9`"5X^0$M8$P`\`"BWP/XF7TF@,\!`_BQ?2T00P`F:`4"^H89`'@I
M&0`M$%$``_BM?24HL``M$$T``_BE?+AO&`"ZP!@`)6BX`2TH10#X`*+?`_BX
M?":`[0$#^-%]+1!#`"9P#`+ZAA@`>&$8`"T040`#^,Y])6"0`2T03@`#^(Q]
MN'<9`+K(&0`E<-D!+6!,```!HM\#^)E])H"N`0/X\7TM$$,`)G@%`OJ&&0!X
M*1D`+1!1``/X[WTE*+``+1!/``/XI7RX?Q@`NL`8`"5X^`$M*$4`"`&BWP/X
MN'PF@,\!`_BQ?2T00P`F:`P"^H88`'AA&``M$%$``_BM?25@D`$M$$T``_B,
M?;AO&0"ZR!D`)6BY`2U@3``0`:+?`_B9?2:`[0$#^-%]+1!#`"9P!0+ZAAD`
M>"D9`"T040`#^,Y])2BP`"T03@`#^*5\N'<8`+K`&``E<-@!+2A%`!@!HM\#
M^+A\)H"N`0/X\7TM$$,`)G@,`OJ&&`!X81@`+1!1``/X[WTE8)`!+1!/``/X
MC'VX?QD`NL@9`"5X^0$M8$P`(`&BWP/XF7TF@,\!`_BQ?2T00P`F:`4"^H89
M`'@I&0`M$%$``_BM?24HL``M$$T``_BE?+AO&`"ZP!@`+2A%`"5HN`$H`:+?
M`_BQ?";`[0$#^-!]+1!#`"9P#`/ZQA$`>&$1`"T04``#^,Y])6"8`2T03@`#
M^(Q]N'<9`+K(&0`E<-D!+6!,`#`!HM\#^)!])L"N`0/X^7TM$$,`)G@%`_K&
M$`!X*1``+1!9``/X[WTE*+@`+1!/`+C'$0`#^*5\NH@1`"7`$0,M*$4`.`&B
MWR9XV`$#^+E\+1!#``/XK7TF8.P!^HX9`'AY&0`M$$T``_B,?;AO$``M$$P`
MNH`0`"5@\0$E:+`!+1!,`$`!K-\F@`T#`_A/?"U@@P$F$`4"`_C.?2U@C@$#
M^$)\^G8/`'@I#P"X'QD`+6""`;K(&0#&(P(\)1AY`"4HK@!(`;G?-^]"-+@0
M`@`#^&Y\+6"%`24HHP$#^(Q])("N`2W((@,D**\``_@8?RW`.`,E*+``>,D,
M`/J&#``M*+@`)<`P`[B/#P`M*+@`NG@/``/XN'PE>"\"4`&EWR48;P`DR.X!
M+2BB`"08;``#^*U]+6BM`/J&&``E&'D`N"\,`'C)&`"Z8`P`)2BL`"T8;0`E
M8#`#6`&YWP/XK7PM&&P`)6#E`0/X8WPD@.T!)&"8`2W((@,MR"X#^HX#`"5@
MD`%X@0,`N)<8`+IP&``M8)D!)<`1`BU@F`$#^)A])7!.`F`!K-\E**X`),C-
M`2U@@@$D**,``_CO?2UXCP&XAP,`)2BY`'AA&`#ZSA@`NA@#`"48`P(E8)D!
M+2BO`&@!N=\#^&]\+2BL`"5@PP$#^*5\)(#/`21@F`$MR"(#+<@M`_J.!0`E
M8)`!>($%`+B7&`"Z:!@`+6"9`27`$0(M8)@!`_B8?25H30)P`:S?)1AM`"3(
MKP$M8((!)!AE``/XSGTM<(X!N(<%`"48>0!X81@`^LX8`+HH!0`E*`4")6"9
M`2T8;@!X`;G?`_BN?"T8;``E8*4!`_AC?"2`K@$D8)@!+<@B`RW(+P/ZC@,`
M)6"0`7B!`P"XEQ@`NG@8`"U@F0$EP!$"+6"8`0/XF'TE>$\"@`&LWR4HKP`D
MR.X!+6""`20HHP`#^*U]+6B-`;B'`P`E*+D`>&$8`/K.&`"Z&`,`)1@#`B5@
MF0$M**T`B`&YWP/X;7PM**P`)6#C`0/XI7PD@.T!)&"8`2W((@,MR"X#^HX%
M`"5@D`%X@04`N)<8`+IP&``M8)D!)<`1`BU@F`$#^)A])7!.`I`!K-\E&&X`
M),C-`2U@@@$D&&4``_CO?2UXCP&XAP4`)1AY`'AA&`#ZSA@`NB@%`"4H!0(E
M8)D!+1AO`)@!N=\#^*]\+1AL`"5@Q0$#^&-\)(#/`21@F`$MR"(#+<@M`_J.
M`P`E8)`!>($#`+B7&`"Z:!@`+6"9`27`$0(M8)@!`_B8?25H30*@`:S?)2BM
M`"3(KP$M8((!)"BC``/XSGTM<(X!N(<#`"4HN0!X81@`^LX8`+H8`P`E&`,"
M)6"9`2THK@"H`;G?`_AN?"THK``E8*,!`_BE?"2`K@$D8)@!+<@B`RW(+P/Z
MC@4`)6"0`7B!!0"XEQ@`NG@8`"U@F0$EP!$"+6"8`0/XF'TE>$\"L`&LWR48
M;P`DR.X!+6""`20890`#^*U]+6B-`248>0!X81@`^LX8`"5@F0$M&&T`N(<%
M`"T8;`"Z*`4``_AY?"4H!0*X`:/?`_BM?"5@Y0$D@.T!)&"8`2T88@`M&&X`
M^HX9`"5@D`%X@1D`N)<8`+IP&``M8(,!)1@1`B5P3@(M8(,!P`&CWR4HK@`#
M^)A]+1AB`"1@S0$D*+D``_CO?2UX;P#ZAA@`N(\9`"4HK`"Z&!D`>&$8`"48
M(P(E8)`!R`&YWRTHKP`M**P``_AO?"5@PP$#^*5\)(#/`21@F`$MR"(#+<@M
M`_J.!0`E8)`!N)<8`'B!!0"Z:!@`)<!-`BU@F0$E:!$"+6"-`=`!K=\E&'@`
M`_B,?23(#P,M:*(!)!AE``/XSGTM<*X!)1AY`'AI#`#ZS@P`)6BY`2T8;@"X
M=P4`NB@%`"4HQ0'8`;#?+1AM``/X8WP#^*Y\)6@%`R20#@,M@`("^HX#`"1H
MK`%XR0,`+7@/`B5HL@$ER#$#+6BO`0/X.7^X?PP`NF`,`.`!L-\E>.P!+6BY
M`0/XN7TE**\`)"BC`"20[@$M@`("^HX9``/X#']XP1D`+6`,`B40L@`E*!$#
MN,<#`+H8`P`EP`,#+1!,``/XI7PM*$4`)ACX`3%E`CPF&&T`ZV!"9.@!K=]X
M$`(``_BP?'AA$`#ZCA``+6BB`2UHK@$#^&-\)7"1`2T8;0`#^,Y]N&\9`+K(
M&0`E:+D!+7!N``/X['WP`:_?`_C9?288#0,M>.(!^HX9`"8890!X*1D`+6#L
M`24HL0`#^&-\+1AL``/XI7RX9Q``NH`0`"5@D`$M*&4`^`&CWP/XL'PF>*P!
M`_@1?RT88@`F<.X!>,$0`/I^$``M&'$``_C.?27`#P,M&&X`N'\9``/X&'^Z
MR!D`)7CY`2W`>````J/?`_@9?R9PCP$#^+%]+1AB`"9HQ0'Z=AD`>"D9`"T8
M<0`#^*U])2BN`"T8;0"X=Q```_BE?+J`$``E<-`!+2AE``@"H]\#^+!\)FCN
M`0/XD7TM&&(`)FBX`7AA$`#ZQA``+1AQ``/XK7TE8)@!+1AM``/XC'VX;QD`
MNL@9`"5HN0$M8&P`$`*CWP/XF'TFR,T!`_CQ?2T88@`F>"4#^LX8`'@I&``M
M&'$``_CO?24HN0`M&&\``_BE?+A_$`"Z@!``)7CP`2TH90`8`J/?`_BY?":`
MKP$#^-%]+1AB`"9P#`+ZAAD`>&$9`"T8<0`#^,Y])6"0`2T8;@`#^(Q]N'<8
M`+K`&``E<-@!+6!L`"`"H]\#^)A])H#N`0/XL7TM&&(`)F@%`OJ&&`!X*1@`
M+1AQ``/XK7TE*+``+1AM``/XI7RX;QD`NL@9`"5HN0$M*&4`*`*CWP/XN7PF
M@,T!`_CQ?2T88@`F>`P"^H89`'AA&0`M&'$``_CO?25@D`$M&&\``_B,?;A_
M&`"ZP!@`)7CX`2U@;``P`J/?`_B8?2:`KP$#^-%]+1AB`"9P!0+ZAA@`>"D8
M`"T8<0`#^,Y])2BP`"T8;@`#^*5\N'<9`+K(&0`E<-D!+2AE`#@"H]\#^+E\
M)H#N`0/XL7TM&&(`)F@,`OJ&&0!X81D`+1AQ``/XK7TE8)`!+1AM``/XC'VX
M;Q@`NL`8`"5HN`$M8&P`0`*CWP/XF'TF@,T!`_CQ?2T88@`F>`4"^H88`'@I
M&``M&'$``_CO?24HL``M&&\``_BE?+A_&0"ZR!D`)7CY`2TH90!(`J/?`_BY
M?":`KP$#^-%]+1AB`"9P#`+ZAAD`>&$9`"T8<0`#^,Y])6"0`2T8;@`#^(Q]
MN'<8`+K`&``E<-@!+6!L`%`"H]\#^)A])H#N`0/XL7TM&&(`)F@%`OJ&&`!X
M*1@`+1AQ``/XK7TE*+``+1AM``/XI7RX;QD`NL@9`"5HN0$M*&4`6`*CWP/X
ML'PFR,T!`_CQ?2T88@`F>"P#^LX0`'AA$``M&'$``_CO?25@F0$M&&\``_B,
M?;A_&`"ZP!@`)7CX`2U@;`!@`J/?`_B8?2;(KP$#^-%]+1AB`"9P)0/ZSA@`
M>"D8`"T8<0`#^,Y])2BY`"T8;@"XSQ```_BE?+J`$``ER#`#+2AE`&@"H]\#
M^+%\)G#Y`0/XL'TM&&(`)F#,`7AI$0#Z=A$`+1AP``/XC'TE:*X!+1AL`+AW
M&``#^*U]NL`8`"5PV`$M:&T`<`*CWP/XL'TF8"X#+1AB``/X[WTF*(4!>,$0
M`/IF$``M&&\``_BE?"7`#`.X9Q$`NH@1`"5@D0$M&&4``_@8?W@"I=\MP'@`
M)AC,`0/X#W\M**(``_@Y?R88;0`M*+D``_AC?'C)#P#ZC@\`+2BC`"48,0.X
M;Q``+2BC`+J`$`"``J/?)6BP`2T08@`F&(T!`_BE?"T02P`#^,Y])AAX`'A9
M!0`M$$X``_AC?/IV!0`M$$,`)1AN`2T00P`#^$)\N!\/`+IX#P```(+\)1AO
M`"T89@"(`JO?+3"G`2THJ``M$(H!```GW0/XI7P#^&-\`_C&?`/X0GP(`(7\
M$`"#_!@`AOP(`&<5(`""_+@"O]^P`KS?J`*RWZ`"L=^8`K#?"`#@`\`"O6=H
M@9G?"?@@`P````#P_[UG``"\_P(`'#PMX)D#*-.<9WB!F=\(`+__"?@@`X``
M!"1=3`4\?VZE9'@H!0#G=P8D/0P$/!``1?Q%9P<\>#0&`#(0!3P?+H1D`2/G
M9(FKQF1V5*5D."$$````1_P(`$;\&`!%_"``1/PH`$#\,`!`_'@`0*P(`+_?
M``"\WP@`X`,0`+UGL/^]9T``O/\X`+;_,`"U_Q``L?](`+__*`"T_R``L_\8
M`++_"`"P_R@`@]SX$`8`+1!#``(`'#P#^$)\+>"9`RL80P`EJ,``H-*<9S``
MAMPEL(```@!@$"6(H``!`,9D>A\5`'@`Q(XM&&8`*`#"_C``P_Y$`(`4.`#0
M9D``HBI7`$`44("4W\#_M2:#R;)^`0!39KB9$P`MF#,"H$:49@<`)&H/`"EJ
M```D;A<`*&H?`"=J)P`F:B\`)6HW`"-J/P`B:@@`*6X0`"AN&``G;B``)FXH
M`"5N,``C;C@`(FX'``2R```$M@\`";((``FV%P`(LA``"+8?``>R&``'MB<`
M!K(@``:V+P`%LB@`!;8W``.R,``#MB4@P`(_``*R)<B``C@``K;Y^1$$0``Q
M9MO_,Q8`````@)$2`".HL@+8@9G?)3"@`B4H8`()^"`#)2```G@`U:Y(`+_?
M0`"\WS@`MM\P`+7?*`"TWR``L]\8`++?$`"QWP@`L-\(`.`#4`"]9P````!`
M`!,D(Q!D`BH850`*$*,"V(&9WR4P0``E*"`"+2`$`@GX(`,ED$``>`#"CB$0
M4@#G_U,4>`#"KE"`E-\E(,`"H$:49B7(@`+/^1$$(ZBR`JC_`!`MB#("U_\`
M$"68(`+`_[UG,`"\_R@`M?\8`+/_$`"R_P@`L?\``+#_.`"__R``M/\H`*+<
M*`"CC"6`H``P`*6,PRA"?`(`'#R@&`-\`0!&)"W@F0,X`!5F`APC`*`H!7RX
MT)QG`BPE`"T0H@(ED&``.0#'*(#_`R0EB(``>(*9WR68H````$.@6`#@%"T@
MI@)```(D4("4WR,P1@`E*```"?@@`Z!&E&8ER(`"H?D1!"4@``)X@IG?.``&
M)"4H```)^"`#)2"@`B4@``(ER(`"<``3KI?Y$01T`!*N```"WD""F=\Z%@(`
M```BH@```MXE(``".A0"``$`(J(```+>.A("``(`(J(```+>`P`BH@@``MXZ
M%@(`!``BH@@``MXZ%`(`!0`BH@@``MXZ$@(`!@`BH@@``MX'`"*B$``"WCH6
M`@`(`"*B$``"WCH4`@`)`"*B$``"WCH2`@`*`"*B$``"W@L`(J(8``+>.A8"
M``P`(J(8``+>.A0"``T`(J(8``+>.A("``X`(J(8``+>#P`BHB```MXZ%@(`
M$``BHB```MXZ%`(`$0`BHB```MXZ$@(`$@`BHB```MX)^"`#$P`BHC@`O]\P
M`+S?*`"UWR``M-\8`+/?$`"RWP@`L=\``+#?"`#@`T``O6<X``(D4("4WR,P
M1@`E*```"?@@`Z!&E&:Q_P`0)2```@``````````P/^]9S``O/\"`!P\+>"9
M`[#.G&<0`++_``"P_\"`DM_(@)#?T("9WR^04`(H`+7_(`"T_Q@`L_\X`+__
M"`"Q__N0$@`EF(``):"@`#[N$00EJ,``"@!`$B6(```````````9WB4PH`(E
M*(`")2!@`@GX(`,!`#%F^?]1%@@`$&8X`+_?,`"\WR@`M=\@`+3?&`"SWQ``
MLM\(`+'?``"PWP@`X`-``+UG"`#@`P````#P_[UG``"\_P(`'#PMX)D#`,Z<
M9TB`@M^8@IG?``!'W`@`O_\)^"`#``````@`O]\``+S?"`#@`Q``O6<`````
M$("9WR5XX`,)^"`#:``89!"`F=\E>.`#"?@@`V<`&&00@)G?)7C@`PGX(`-F
M`!AD$("9WR5XX`,)^"`#90`89!"`F=\E>.`#"?@@`V0`&&00@)G?)7C@`PGX
M(`-B`!AD$("9WR5XX`,)^"`#80`89!"`F=\E>.`#"?@@`V``&&00@)G?)7C@
M`PGX(`-=`!AD$("9WR5XX`,)^"`#7``89!"`F=\E>.`#"?@@`UL`&&00@)G?
M)7C@`PGX(`-:`!AD$("9WR5XX`,)^"`#60`89!"`F=\E>.`#"?@@`U@`&&00
M@)G?)7C@`PGX(`-7`!AD$("9WR5XX`,)^"`#5@`89!"`F=\E>.`#"?@@`U4`
M&&00@)G?)7C@`PGX(`-4`!AD$("9WR5XX`,)^"`#4P`89!"`F=\E>.`#"?@@
M`U(`&&00@)G?)7C@`PGX(`-0`!AD$("9WR5XX`,)^"`#3P`89!"`F=\E>.`#
M"?@@`TX`&&00@)G?)7C@`PGX(`--`!AD$("9WR5XX`,)^"`#2P`89!"`F=\E
M>.`#"?@@`TH`&&00@)G?)7C@`PGX(`-'`!AD$("9WR5XX`,)^"`#1@`89!"`
MF=\E>.`#"?@@`T4`&&00@)G?)7C@`PGX(`-"`!AD$("9WR5XX`,)^"`#00`8
M9!"`F=\E>.`#"?@@`T``&&00@)G?)7C@`PGX(`,_`!AD$("9WR5XX`,)^"`#
M/@`89!"`F=\E>.`#"?@@`SP`&&00@)G?)7C@`PGX(`,Z`!AD$("9WR5XX`,)
M^"`#.0`89!"`F=\E>.`#"?@@`S@`&&00@)G?)7C@`PGX(`,W`!AD$("9WR5X
MX`,)^"`#-@`89!"`F=\E>.`#"?@@`S4`&&00@)G?)7C@`PGX(`,T`!AD$("9
MWR5XX`,)^"`#,P`89!"`F=\E>.`#"?@@`S(`&&00@)G?)7C@`PGX(`,Q`!AD
M$("9WR5XX`,)^"`#,``89!"`F=\E>.`#"?@@`R\`&&00@)G?)7C@`PGX(`,N
M`!AD$("9WR5XX`,)^"`#+0`89!"`F=\E>.`#"?@@`RP`&&00@)G?)7C@`PGX
M(`,K`!AD$("9WR5XX`,)^"`#*@`89!"`F=\E>.`#"?@@`R@`&&00@)G?)7C@
M`PGX(`,G`!AD$("9WR5XX`,)^"`#)@`89!"`F=\E>.`#"?@@`R4`&&00@)G?
M)7C@`PGX(`,D`!AD`````````````````````/#_O6<``+S_`@`</"W@F0,(
M`+__(,J<9P@`O]\``+S?"`#@`Q``O6<```````````$``@``````)7,O)7,`
M```N`````````"\`````````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````
M97AE```````O<')O8R\E:2\E<P``````4$%27U1%35```````````%!!4E]0
M4D]'3D%-10`````Z`````````"5S)7,E<P``4$523#5,24(``````````%!%
M4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'````
M`````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!0
M05)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!3CT`
M```````Q`````````$Q$7TQ)0E)!4EE?4$%42`!54T52`````%-94U1%30``
M+W1M<`````!435!$25(``%1%35!$25(`5$5-4`````!435```````%5315).
M04U%```````````E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*````````4$%42`````!P87)L`````"YP87(`````)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M```````8`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D52
M4TE/3@`````Q+C`U,@```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90``````
M`"TM````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<
M;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92!O<B!L87-T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P
M;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@
M,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P
M*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?
M<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O
M<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR96%D(%]&2"P@
M)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H
M;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA
M9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S
M:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P
M;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B
M=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F
M:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@
M(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C
M<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D
M8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS
M92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@
M/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M
M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T
M92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H
M)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F
M:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@
M("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z
M("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5E
M;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@
M<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%2
M7R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H
M)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S
M*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@
M)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R
M961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@
M9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM
M>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@
M*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R
M968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]
M*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B
M+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY
M("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL
M92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO
M)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^
M<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS
M<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD
M8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P
M-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A
M<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI:
M:7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE
M;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U
M=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@
M+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D
M8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E
M=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@
M?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%
M04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B
M.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E
M7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R
M:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L
M;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A
M<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("([
M"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y]
M.PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*
M;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#
M3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>
M4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P``
M`````````````````"]L:6(V-"]L9"YS;RXQ````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"@?````
M````N!X`````````````````````````````_____P````````````````AJ
M````````````````````````````````````````````````````````````
M@!`;````````@&$````````H8@```````````@``````.+`!``````!`LP$`
M```````````````````!``````#000```````&`J````````@"L`````````
M-@````````A=````````D%T```````!X7P```````+`N````````:#<`````
M```P8@```````""P`0```````$4```````#XKP$``````/"O`0``````R!H`
M````````````````````````````\&4```````#@90```````-!E````````
MP&4```````"P90``````````````````H&4```````"090```````(!E````
M````<&4```````!@90```````%!E````````0&4````````P90```````"!E
M````````$&4`````````90```````/!D````````X&0```````#09```````
M`,!D````````L&0```````"@9```````````````````D&0`````````````
M`````(!D````````<&0```````!@9````````%!D````````0&0`````````
M````````````````````,&0````````@9````````!!D````````````````
M``````````````!D````````\&,``````````````````.!C````````T&,`
M``````#`8P```````+!C``````````````````"@8P```````)!C````````
M@&,```````!P8P```````&!C````````4&,```````!`8P```````#!C````
M````(&,````````08P````````!C````````\&(`````````````````````
M````````X&(```````#08@```````,!B``````````````````"P8@``````
M`*!B````````D&(```````"`8@```````'!B````````0+,!``````!'0T,Z
M("A$96)I86X@,3`N,BXQ+38I(#$P+C(N,2`R,#(Q,#$Q,```4!\`````?Y#X
M____``````````!0````'0```!\```#((`````#_D/C___\``````````#`!
M```=````'P```.@B``````.0^/___P````````````$``!T````?````J",`
M`````Y#X____```````````@````'0```!\````@)0`````_D/C___\`````
M`````%`0```=````'P```*@F`````/^0^/___P``````````8````!T````?
M````:"D``````9#X____```````````@````'0```!\````(*@``````D/C_
M__\``````````!`````=````'P```&`J``````^0^/___P``````````8"``
M`!T````?````:"L`````````````````````````````'0```!\```"`*P``
M``#_T/C___\``````````&`1```=````'P```"`N````````````````````
M`````````!T````?````4"X``````)#X____```````````0````'0```!\`
M``"P+@````#_T/C___\``````````*`````=````'P`````U``````.0^/__
M_P``````````,````!T````?````N#4``````)#X____```````````0````
M'0```!\`````-@`````?D/C___\``````````%`````=````'P```&@W````
M`/_0^/___P``````````$((``!T````?````T$$`````/Y#X____````````
M``!0````'0```!\`````10`````/D/C___\``````````$`````=````'P``
M`!`;`````#^0^/___P``````````<````!T````?````H$8`````!Y#X____
M``````````#``@``'0```!\````(70``````D/C___\``````````!`````=
M````'P```)!=`````'^0^/___P``````````4````!T````?````>%\`````
M/Y#X____``````````!`````'0```!\```"`80`````_D/C___\`````````
M`$`````=````'P```"AB`````````````````````````````!T````?````
M,&(``````)#X____```````````0````'0```!\```!!#P```&=N=0`!!P``
M``0!`"YS:'-T<G1A8@`N34E04RYA8FEF;&%G<P`N34E04RYO<'1I;VYS`"YN
M;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YD>6YA;6EC`"YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U8G,`+F9I;FD`+G)O9&%T
M80`N:6YT97)P`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M9&%T80`N<FQD7VUA<``N9V]T`"YS9&%T80`N8G-S`"YC;VUM96YT`"YP9'(`
M+F=N=2YA='1R:6)U=&5S````````````````````````````````````````
M``````````````````````````````````````````````````````L````J
M``!P`@````````!P`@```````'`"````````&`````````````````````@`
M````````&``````````:````#0``<`(```@`````B`(```````"(`@``````
M`+@!```````````````````(``````````$`````````*`````<````"````
M`````$`$````````0`0````````D````````````````````!```````````
M`````````#L````'`````@````````!D!````````&0$````````(```````
M``````````````0```````````````````!)````!@````(`````````B`0`
M``````"(!````````'`"````````"``````````(`````````!``````````
M4@````4````"`````````/@&````````^`8````````P`P````````<`````
M````"``````````$`````````%@````+`````@`````````H"@```````"@*
M````````V`D````````(`````@````@`````````&`````````!@`````P``
M``(``````````!0`````````%````````/($```````````````````!````
M````````````````:````/___V\"`````````/(8````````\A@```````#2
M``````````<``````````@`````````"`````````'4```#^__]O`@``````
M``#(&0```````,@9````````L``````````(`````P````@`````````````
M``````"$````"0````(`````````>!H```````!X&@```````%``````````
M!P`````````(`````````!``````````C0````$````&`````````,@:````
M````R!H```````!`````````````````````!````````````````````),`
M```!````!@`````````0&P```````!`;````````8$<`````````````````
M`!````````````````````"9`````0````8`````````<&(```````!P8@``
M`````*`#```````````````````(````````````````````I0````$````&
M`````````!!F````````$&8````````H````````````````````!```````
M`````````````*L````!`````@````````!`9@```````$!F````````D#\`
M`````````````````!````````````````````"S`````0````(`````````
MT*4```````#0I0````````\````````````````````!````````````````
M````NP````$````"`````````."E````````X*4````````$````````````
M````````!````````````````````,4````.`````P````````#PKP$`````
M`/"O````````"`````````````````````@`````````"`````````#1````
M#P````,`````````^*\!``````#XKP````````@````````````````````(
M``````````@`````````W0````$````#``````````"P`0```````+``````
M```P````````````````````$````````````````````.,````!`````P``
M```````PL`$``````#"P````````"`````````````````````@`````````
M``````````#L`````0````,``!``````0+`!``````!`L``````````#````
M```````````````0``````````@`````````\0````$````#```0`````$"S
M`0``````0+,````````(````````````````````"```````````````````
M`/@````(`````P````````!0LP$``````$BS````````,!``````````````
M`````!````````````````````#]`````0```#````````````````````!(
MLP```````"<````````````````````!``````````$`````````!@$```$`
M````````````````````````<+,```````"``P``````````````````!```
M``````````````````L!``#U__]O`````````````````````/"V````````
M$`````````````````````$````````````````````!`````P``````````
M````````````````MP```````!L!```````````````````!````````````
&````````
